stalker.ext.validatedList.ValidatedList
=======================================

.. inheritance-diagram::
     stalker.ext.validatedList.ValidatedList
     :parts: 1

.. currentmodule:: stalker.ext.validatedList

.. autoclass:: ValidatedList
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ValidatedList.__init__
      ~ValidatedList.append
      ~ValidatedList.extend
      ~ValidatedList.insert
      ~ValidatedList.pop
      ~ValidatedList.remove
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~ValidatedList.count
      ~ValidatedList.index
      ~ValidatedList.reverse
      ~ValidatedList.sort
   
   